@@ -6,7 +6,7 @@ use strict;
 use warnings; 
 no warnings 'recursion';
 
-use Sub::Fallback q(fallback);
+use Sub::Fallback qw(fallback);
 
 $Sub::Fallback::Debug = 1;
 
@@ -26,5 +26,5 @@ sub increase {
     
 sub loop { 
     fallback(0) if $i == 20;
-    fallback(1, 1);
+    fallback(1,1);
 }
